@@ -1,6 +1,7 @@
 from unittest.mock import Mock, call
 
 import pytest
+from typing_extensions import Annotated
 
 from psygnal import EmissionInfo, Signal, SignalGroup
 
@@ -10,11 +11,6 @@ class MyGroup(SignalGroup):
     sig2 = Signal(str)
 
 
-class MyStrictGroup(SignalGroup, strict=True):
-    sig1 = Signal(int)
-    sig2 = Signal(int)
-
-
 def test_signal_group():
     assert not MyGroup.is_uniform()
     group = MyGroup()
@@ -28,6 +24,10 @@ def test_signal_group():
 def test_uniform_group():
     """In a uniform group, all signals must have the same signature."""
 
+    class MyStrictGroup(SignalGroup, strict=True):
+        sig1 = Signal(int)
+        sig2 = Signal(int)
+
     assert MyStrictGroup.is_uniform()
     group = MyStrictGroup()
     assert group.is_uniform()
@@ -43,6 +43,22 @@ def test_uniform_group():
     assert str(e.value).startswith("All Signals in a strict SignalGroup must")
 
 
+def test_nonhashable_args():
+    """Test that non-hashable annotations are allowed in a SignalGroup"""
+
+    class MyGroup(SignalGroup):
+        sig1 = Signal(Annotated[int, {"a": 1}])  # type: ignore
+        sig2 = Signal(Annotated[float, {"b": 1}])  # type: ignore
+
+    assert not MyGroup.is_uniform()
+
+    with pytest.raises(TypeError):
+
+        class MyGroup2(SignalGroup, strict=True):
+            sig1 = Signal(Annotated[int, {"a": 1}])  # type: ignore
+            sig2 = Signal(Annotated[float, {"b": 1}])  # type: ignore
+
+
 @pytest.mark.parametrize("direct", [True, False])
 def test_signal_group_connect(direct: bool):
     mock = Mock()
