@@ -4,21 +4,13 @@ import time
 from contextlib import suppress
 from functools import partial, wraps
 from inspect import Signature
-from typing import Optional, Type
+from typing import Optional
 from unittest.mock import MagicMock, Mock, call
 
 import pytest
 
 from psygnal import EmitLoopError, Signal, SignalInstance, _compiled
-from psygnal._signal import (
-    SlotCaller,
-    _BoundMethodCaller,
-    _FunctionCaller,
-    _get_method_name,
-    _PartialMethodCaller,
-    _SetattrCaller,
-    _SetitemCaller,
-)
+from psygnal._weak_callback import WeakCallback
 
 
 def stupid_decorator(fun):
@@ -136,7 +128,6 @@ def test_decorator():
 
     with pytest.raises(EmitLoopError) as e:
         emitter.one_int.emit(1)
-    assert e.value.slot is boom
     assert e.value.__cause__ is err
     assert e.value.__context__ is err
 
@@ -245,32 +236,24 @@ def test_slot_types(type_: str) -> None:
     signal = emitter.one_int
     assert len(signal) == 0
     obj = MyObj()
-    caller_type: Type[SlotCaller]
 
     if type_ == "setattr":
         signal.connect_setattr(obj, "x")
-        caller_type = _SetattrCaller
     elif type_ == "setitem":
         signal.connect_setitem(obj, "x")
-        caller_type = _SetitemCaller
     elif type_ == "function":
         signal.connect(f_int)
-        caller_type = _FunctionCaller
     elif type_ == "lambda":
         signal.connect(lambda x: None)
-        caller_type = _FunctionCaller
     elif type_ == "method":
         signal.connect(obj.f_int)
-        caller_type = _BoundMethodCaller
     elif type_ == "partial_method":
         signal.connect(partial(obj.f_int_int, 2))
-        caller_type = _PartialMethodCaller
 
     assert len(signal) == 1
 
     stored_slot = signal._slots[-1]
-    assert isinstance(stored_slot, caller_type)
-    assert callable(stored_slot.slot())
+    assert isinstance(stored_slot, WeakCallback)
     assert stored_slot == stored_slot
 
     with pytest.raises(TypeError):
@@ -298,7 +281,6 @@ def test_basic_signal_with_sender_receiver():
     with pytest.raises(EmitLoopError) as e:
         emitter.one_int.emit(1)
 
-    assert e.value.slot == receiver.assert_not_sender
     assert isinstance(e.value.__cause__, AssertionError)
     assert isinstance(e.value.__context__, AssertionError)
 
@@ -687,31 +669,6 @@ def test_signals_on_unhashables():
     e.signal.emit(1)
 
 
-def test_debug_import(monkeypatch):
-    """Test that PSYGNAL_UNCOMPILED always imports the pure python file."""
-    import sys
-
-    import psygnal._signal
-
-    if not psygnal._signal.__file__.endswith(".py"):
-        assert psygnal._compiled
-
-    monkeypatch.delitem(sys.modules, "psygnal")
-    monkeypatch.delitem(sys.modules, "psygnal._signal")
-    monkeypatch.setenv("PSYGNAL_UNCOMPILED", "1")
-
-    import psygnal
-
-    assert not psygnal._compiled
-
-
-def test_get_method_name():
-    obj = MyObj()
-    assert _get_method_name(obj.f_int_decorated_stupid)[1] == "f_int_decorated_stupid"
-    assert _get_method_name(obj.f_int_decorated_good)[1] == "f_int_decorated_good"
-    assert _get_method_name(obj.f_any_assigned)[1] == "f_any_assigned"
-
-
 def test_property_connect():
     class A:
         def __init__(self):
@@ -770,11 +727,10 @@ def test_connect_setitem():
     assert my_obj._dict == {"x": 5}
 
     obj = object()
-    with pytest.warns(RuntimeWarning):
-        with pytest.raises(TypeError, match="does not support __setitem__"):
-            t.sig.connect_setitem(obj, "x")
+    with pytest.raises(TypeError, match="does not support __setitem__"):
+        t.sig.connect_setitem(obj, "x")
 
-    with pytest.raises(ValueError):
+    with pytest.raises(TypeError):
         t.sig.disconnect_setitem(obj, "x", missing_ok=False)
 
 
@@ -796,6 +752,8 @@ def test_repr_not_used():
     mock.assert_not_called()
 
 
+# b.signal2.emit will warn that compiled SignalInstances cannot be weakly referenced
+@pytest.mark.filterwarnings("ignore:failed to create weakref:UserWarning")
 def test_signal_emit_as_slot():
     class A:
         signal1 = Signal(int)
@@ -864,34 +822,15 @@ def test_emit_loop_exceptions():
 )
 def test_weakref_disconnect(slot):
     """Test that a connected method doesn't hold strong ref."""
-    from psygnal._signal import _PARTIAL_CACHE, _prune_partial_cache
 
     emitter = Emitter()
     obj = MyObj()
 
-    _prune_partial_cache()
-    assert not _PARTIAL_CACHE
-
     assert len(emitter.one_int) == 0
     cb = partial(obj.f_int_int, 1) if slot == "partial" else getattr(obj, slot)
-    cb_id = id(cb)
-    assert cb_id not in _PARTIAL_CACHE
     emitter.one_int.connect(cb)
-    assert (cb_id in _PARTIAL_CACHE) == (slot == "partial")
     assert len(emitter.one_int) == 1
     emitter.one_int.emit(1)
     assert len(emitter.one_int) == 1
     emitter.one_int.disconnect(cb)
     assert len(emitter.one_int) == 0
-    assert cb_id not in _PARTIAL_CACHE
-
-
-class T:
-    sig = Signal(
-        str,
-        int,
-        name="test",
-        check_nargs_on_connect=False,
-        check_types_on_connect=True,
-        description="test signal",
-    )
